%define anolis_release 3
%global shortname srtp

Name:		libsrtp
Version:	2.4.2
Release:	%{anolis_release}%{?dist}
Summary:	An implementation of the Secure Real-time Transport Protocol (SRTP)
License:	BSD
URL:		https://github.com/cisco/libsrtp
Source0:	https://github.com/cisco/libsrtp/archive/v%{version}.tar.gz
BuildRequires:  make gcc
BuildRequires:  nss-devel, libpcap-devel

%description
LibSRTP is an open-source library that implements the Secure Real-time
Transport Protocol (SRTP). SRTP is a security protocol that is used to provide
confidentiality, authentication, and integrity protection for VoIP (Voice over
IP) streams, video calls, and other real-time media transmissions.

LibSRTP is designed to be a low-level library, providing developers with the
tools they need to add SRTP security to their applications. It provides support
for a variety of cryptographic algorithms, including AES, SHA-1, and HMAC-SHA1,
and can be used with both RTP (Real-time Transport Protocol) and RTCP (Real-time
Transport Control Protocol) traffic.

LibSRTP is designed to be easy to use, and provides a simple API that developers
can use to add SRTP support to their applications. It supports both unicast and
multicast transmission, and provides support for both RTP and RTCP packets.

One of the key advantages of using LibSRTP is that it provides end-to-end
security for real-time media streams. This means that the media is encrypted at
the source and decrypted only by the intended recipient, ensuring that it cannot
be intercepted or manipulated by third parties. This is essential for
applications that require both privacy and security, such as telemedicine,
financial services, and government communications.

In summary, LibSRTP is a powerful yet easy-to-use library that provides
developers with the tools they need to add end-to-end security to real-time
media streams. Its support for a variety of cryptographic algorithms,
easy-to-use API, and end-to-end security make it an essential tool for developers
of VoIP, video conferencing, and other real-time communications applications.

%package devel
Summary:	Development files for %{name}
Requires:	%{name} = %{version}-%{release}
Requires:	pkgconfig

%description devel
This package contains libraries and header files for
developing applications that use %{name}.

%package tools
Summary:	Tools for testing and decoding SRTP
Requires:	%{name} = %{version}-%{release}

%description tools
Tools for testing and decoding SRTP

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{EVR}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%setup -q -n %{name}-%{version}

%build
export CFLAGS="%{optflags} -fPIC"
%configure --enable-nss
make %{?_smp_mflags} shared_library test

%install
make install DESTDIR=%{buildroot}
find %{buildroot} -name '*.la' -exec rm -f {} ';'
find %{buildroot} -name '*.a' -exec rm -f {} ';'

install -D -p -m 0755 test/rtpw %{buildroot}%{_bindir}/rtpw
install -D -p -m 0755 test/test_srtp %{buildroot}%{_bindir}/test_srtp
install -D -p -m 0755 test/roc_driver %{buildroot}%{_bindir}/roc_driver
install -D -p -m 0755 test/rdbx_driver %{buildroot}%{_bindir}/rdbx_driver
install -D -p -m 0755 test/srtp_driver %{buildroot}%{_bindir}/srtp_driver
install -D -p -m 0755 test/rtp_decoder %{buildroot}%{_bindir}/rtp_decoder
install -D -p -m 0755 test/replay_driver %{buildroot}%{_bindir}/replay_driver

%generate_compatibility_deps

%files
%dir %{abidir}
%{abidir}/*.dump
%{_libdir}/*.so.*
%license LICENSE

%files devel
%{_libdir}/*.so
%{_includedir}/%{shortname}2/
%{_libdir}/pkgconfig/libsrtp2.pc

%files tools
%{_bindir}/*
%{abidir}/*-option.list

%files doc
%doc CHANGES README.md

%changelog
* Thu Apr 13 2023 Xuchun Shang <xuchun.shang@linux.alibaba.com> - 2.4.2-3
- Update the description

* Thu Oct 20 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 2.4.2-2
- optimise spec file & add doc package

* Fri Apr 08 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 2.4.2-1
- Init from upstream version 2.4.2

